@@ -1,2 +1,2 @@
 # Use the fixtures test_mp, test_mp_props, and tmp_env from ixmp.testing
-pytest_plugins = ['ixmp.testing']
+pytest_plugins = ["ixmp.testing"]
