@@ -1,13 +1,12 @@
-import collections
+import logging
+from collections.abc import Mapping
 from functools import lru_cache
 from itertools import product
-import logging
 from warnings import warn
 
 import ixmp
-from ixmp.utils import as_str_list, isscalar
 import pandas as pd
-
+from ixmp.utils import as_str_list, isscalar
 
 log = logging.getLogger(__name__)
 
@@ -24,14 +23,23 @@ class Scenario(ixmp.Scenario):
     `scenario`, `version`, and `annotation`. The `scheme` of a newly-created
     Scenario is always 'MESSAGE'.
     """
-    def __init__(self, mp, model, scenario=None, version=None, annotation=None,
-                 scheme=None, **kwargs):
-        # If not a new scenario, use the scheme stored in the Backend
-        if version == 'new':
-            scheme = scheme or 'MESSAGE'
 
-        if scheme not in ('MESSAGE', None):
-            msg = f'Instantiate message_ix.Scenario with scheme {scheme}'
+    def __init__(
+        self,
+        mp,
+        model,
+        scenario=None,
+        version=None,
+        annotation=None,
+        scheme=None,
+        **kwargs,
+    ):
+        # If not a new scenario, use the scheme stored in the Backend
+        if version == "new":
+            scheme = scheme or "MESSAGE"
+
+        if scheme not in ("MESSAGE", None):
+            msg = f"Instantiate message_ix.Scenario with scheme {scheme}"
             raise ValueError(msg)
 
         super().__init__(
@@ -41,11 +49,11 @@ class Scenario(ixmp.Scenario):
             version=version,
             annotation=annotation,
             scheme=scheme,
-            **kwargs
+            **kwargs,
         )
 
         # Scheme returned by database
-        assert self.scheme == 'MESSAGE', self.scheme
+        assert self.scheme == "MESSAGE", self.scheme
 
     # Utility methods used by .equ(), .par(), .set(), and .var()
 
@@ -59,9 +67,12 @@ class Scenario(ixmp.Scenario):
         # filter() returns a 1-time generator, so convert to a fixed tuple()
         return tuple(
             # Keep only tuples where the idx_set is 'year'
-            filter(lambda e: e[0] == 'year',
-                   # Generate 2-tuples of (idx_set, idx_name)
-                   zip(self.idx_sets(name), self.idx_names(name))))
+            filter(
+                lambda e: e[0] == "year",
+                # Generate 2-tuples of (idx_set, idx_name)
+                zip(self.idx_sets(name), self.idx_names(name)),
+            )
+        )
 
     def _year_as_int(self, name, df):
         """Convert 'year'-indexed columns of *df* to :obj:`int` dtypes.
@@ -75,8 +86,8 @@ class Scenario(ixmp.Scenario):
         year_idx = self._year_idx(name)
 
         if len(year_idx):
-            return df.astype({col_name: 'int' for _, col_name in year_idx})
-        elif name == 'year':
+            return df.astype({col_name: "int" for _, col_name in year_idx})
+        elif name == "year":
             # The 'year' set itself
             return df.astype(int)
         else:
@@ -179,7 +190,7 @@ class Scenario(ixmp.Scenario):
         name : str
             Name of the set.
         """
-        return self._backend('cat_list', name)
+        return self._backend("cat_list", name)
 
     def add_cat(self, name, cat, keys, is_unique=False):
         """Map elements from *keys* to category *cat* within set *name*.
@@ -196,8 +207,7 @@ class Scenario(ixmp.Scenario):
             If `True`, then *cat* must have only one element. An exception is
             raised if *cat* already has an element, or if ``len(keys) > 1``.
         """
-        self._backend('cat_set_elements', name, str(cat), as_str_list(keys),
-                      is_unique)
+        self._backend("cat_set_elements", name, str(cat), as_str_list(keys), is_unique)
 
     def cat(self, name, cat):
         """Return a list of all set elements mapped to a category.
@@ -216,8 +226,8 @@ class Scenario(ixmp.Scenario):
         """
         return list(
             map(
-                int if name == 'year' else lambda v: v,
-                self._backend('cat_get_elements', name, cat)
+                int if name == "year" else lambda v: v,
+                self._backend("cat_get_elements", name, cat),
             )
         )
 
@@ -257,8 +267,8 @@ class Scenario(ixmp.Scenario):
         levels = []
         hierarchy = []
 
-        def recurse(k, v, parent='World'):
-            if isinstance(v, collections.Mapping):
+        def recurse(k, v, parent="World"):
+            if isinstance(v, Mapping):
                 for _parent, _data in v.items():
                     for _k, _v in _data.items():
                         recurse(_k, _v, parent=_parent)
@@ -342,9 +352,8 @@ class Scenario(ixmp.Scenario):
 
         if data:
             warn(
-                "dict() argument to add_horizon(); use year= and "
-                "firstmodelyear=",
-                DeprecationWarning
+                "dict() argument to add_horizon(); use year= and " "firstmodelyear=",
+                DeprecationWarning,
             )
 
             try:
@@ -364,9 +373,7 @@ class Scenario(ixmp.Scenario):
         # Check for existing years
         existing = self.set("year").tolist()
         if len(existing):
-            raise ValueError(
-                f"Scenario has year={existing} and related values"
-            )
+            raise ValueError(f"Scenario has year={existing} and related values")
 
         # Add the year set elements and first model year
         year = sorted(year)
@@ -376,7 +383,7 @@ class Scenario(ixmp.Scenario):
         )
 
         # Calculate the duration of all periods
-        duration = [year[i] - year[i-1] for i in range(1, len(year))]
+        duration = [year[i] - year[i - 1] for i in range(1, len(year))]
 
         # Determine the duration of the first period
         if len(duration) == 0:
@@ -397,11 +404,16 @@ class Scenario(ixmp.Scenario):
 
         # Add the duration_period elements for the first and subsequent periods
         # NB "y" is automatically defined by ixmp's JDBCBackend
-        self.add_par("duration_period", pd.DataFrame({
-            "year": year,
-            "value": [duration_first] + duration,
-            "unit": "y",
-        }))
+        self.add_par(
+            "duration_period",
+            pd.DataFrame(
+                {
+                    "year": year,
+                    "value": [duration_first] + duration,
+                    "unit": "y",
+                }
+            ),
+        )
 
     def vintage_and_active_years(self, ya_args=None, in_horizon=True):
         """Return sets of vintage and active years for use in data input.
@@ -435,12 +447,12 @@ class Scenario(ixmp.Scenario):
         # Prepare lists of vintage (yv) and active (ya) years
         if ya_args:
             if len(ya_args) != 3:
-                raise ValueError('3 arguments are required if using `ya_args`')
+                raise ValueError("3 arguments are required if using `ya_args`")
             ya = self.years_active(*ya_args)
             yv = ya[0:1]  # Just the first element, as a list
         else:
             # Product of all years
-            yv = ya = self.set('year')
+            yv = ya = self.set("year")
 
         # Predicate for filtering years
         def _valid(elem):
@@ -451,8 +463,8 @@ class Scenario(ixmp.Scenario):
         # - Filter only valid years.
         # - Convert to data frame.
         return pd.DataFrame(
-            filter(_valid, product(yv, ya)),
-            columns=['year_vtg', 'year_act'])
+            filter(_valid, product(yv, ya)), columns=["year_vtg", "year_act"]
+        )
 
     def years_active(self, node, tec, yr_vtg):
         """Return years in which *tec* of *yr_vtg* can be active in *node*.
@@ -479,20 +491,24 @@ class Scenario(ixmp.Scenario):
         yv = int(yr_vtg)
 
         # Lifetime of the technology at the node
-        lt = self.par('technical_lifetime', filters=filters).at[0, 'value']
+        lt = self.par("technical_lifetime", filters=filters).at[0, "value"]
 
         # Duration of periods
-        data = self.par('duration_period')
+        data = self.par("duration_period")
         # Cumulative sum for periods including the vintage period
-        data['age'] = data.where(data.year >= yv, 0)['value'].cumsum()
+        data["age"] = data.where(data.year >= yv, 0)["value"].cumsum()
 
         # Return periods:
         # - the tec's age at the end of the *prior* period is less than or
         #   equal to its lifetime, and
         # - at or later than the vintage year.
-        return data.where(data.age.shift(1, fill_value=0) < lt) \
-                   .where(data.year >= yv)['year'] \
-                   .dropna().astype(int).tolist()
+        return (
+            data.where(data.age.shift(1, fill_value=0) < lt)
+            .where(data.year >= yv)["year"]
+            .dropna()
+            .astype(int)
+            .tolist()
+        )
 
     @property
     def firstmodelyear(self):
@@ -502,7 +518,7 @@ class Scenario(ixmp.Scenario):
         -------
         int
         """
-        return int(self.cat('year', 'firstmodelyear')[0])
+        return int(self.cat("year", "firstmodelyear")[0])
 
     def clone(self, *args, **kwargs):
         """Clone the current scenario and return the clone.
@@ -526,7 +542,7 @@ class Scenario(ixmp.Scenario):
         # Call the parent method
         return super().clone(*args, **kwargs)
 
-    def solve(self, model='MESSAGE', solve_options={}, **kwargs):
+    def solve(self, model="MESSAGE", solve_options={}, **kwargs):
         """Solve MESSAGE or MESSAGE-MACRO for the Scenario.
 
         By default, :meth:`ixmp.Scenario.solve` is called with 'MESSAGE' as the
@@ -557,7 +573,7 @@ class Scenario(ixmp.Scenario):
         # Display a warning
         log.warning(EXPERIMENTAL)
 
-        scenario = scenario or '_'.join([self.scenario, 'macro'])
+        scenario = scenario or "_".join([self.scenario, "macro"])
         clone = self.clone(self.model, scenario, keep_solution=False)
         clone.check_out()
 
@@ -565,7 +581,7 @@ class Scenario(ixmp.Scenario):
         MACRO.initialize(clone)
 
         add_model_data(self, clone, data)
-        clone.commit('finished adding macro')
+        clone.commit("finished adding macro")
         calibrate(clone, check_convergence=check_convergence, **kwargs)
         return clone
 
@@ -620,4 +636,4 @@ class Scenario(ixmp.Scenario):
 
         # commit
         if commit:
-            self.commit('Renamed {} using mapping {}'.format(name, mapping))
+            self.commit("Renamed {} using mapping {}".format(name, mapping))
